@@ -35,6 +35,7 @@ from .control import Control
 from .highlighter import NullHighlighter, ReprHighlighter
 from .markup import render as render_markup
 from .measure import Measurement, measure_renderables
+from .pager import Pager, SystemPager
 from .pretty import Pretty
 from .scope import render_scope
 from .segment import Segment
@@ -81,6 +82,8 @@ _TERM_COLORS = {"256color": ColorSystem.EIGHT_BIT, "16color": ColorSystem.STANDA
 class ConsoleOptions:
     """Options for __rich_console__ method."""
 
+    legacy_windows: bool
+    """legacy_windows: flag for legacy windows."""
     min_width: int
     """Minimum width of renderable."""
     max_width: int
@@ -96,6 +99,11 @@ class ConsoleOptions:
     no_wrap: Optional[bool] = False
     """"Disable wrapping for text."""
 
+    @property
+    def ascii_only(self) -> bool:
+        """Check if renderables should use ascii only."""
+        return not self.encoding.startswith("utf")
+
     def update(
         self,
         width: int = None,
@@ -198,12 +206,46 @@ class ThemeContext:
         self.console.pop_theme()
 
 
+class PagerContext:
+    """A context manager that 'pages' content. See :meth:`~rich.console.Console.pager` for usage."""
+
+    def __init__(
+        self,
+        console: "Console",
+        pager: Pager = None,
+        styles: bool = False,
+        links: bool = False,
+    ) -> None:
+        self._console = console
+        self.pager = SystemPager() if pager is None else pager
+        self.styles = styles
+        self.links = links
+
+    def __enter__(self) -> "PagerContext":
+        self._console._enter_buffer()
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
+        if exc_type is None:
+            with self._console._lock:
+                buffer: List[Segment] = self._console._buffer[:]
+                del self._console._buffer[:]
+                segments: Iterable[Segment] = buffer
+                if not self.styles:
+                    segments = Segment.strip_styles(segments)
+                elif not self.links:
+                    segments = Segment.strip_links(segments)
+                content = self._console._render_buffer(segments)
+            self.pager.show(content)
+        self._console._exit_buffer()
+
+
 class RenderGroup:
     """Takes a group of renderables and returns a renderable object that renders the group.
 
     Args:
         renderables (Iterable[RenderableType]): An iterable of renderable objects.
-
+        fit (bool, optional): Fit dimension of group to contents, or fill available space. Defaults to True.
     """
 
     def __init__(self, *renderables: "RenderableType", fit: bool = True) -> None:
@@ -229,8 +271,12 @@ class RenderGroup:
         yield from self.renderables
 
 
-def render_group(fit: bool = False) -> Callable:
-    """A decorator that turns an iterable of renderables in to a group."""
+def render_group(fit: bool = True) -> Callable:
+    """A decorator that turns an iterable of renderables in to a group.
+
+    Args:
+        fit (bool, optional): Fit dimension of group to contents, or fill available space. Defaults to True.
+    """
 
     def decorator(method):
         """Convert a method that returns an iterable of renderables in to a RenderGroup."""
@@ -341,7 +387,7 @@ class Console:
         force_terminal (Optional[bool], optional): Enable/disable terminal control codes, or None to auto-detect terminal. Defaults to None.
         force_jupyter (Optional[bool], optional): Enable/disable Jupyter rendering, or None to auto-detect Jupyter. Defaults to None.
         theme (Theme, optional): An optional style theme object, or ``None`` for default theme.
-        file (IO, optional): A file object where the console should write to. Defaults to stdoutput.
+        file (IO, optional): A file object where the console should write to. Defaults to stdout.
         width (int, optional): The width of the terminal. Leave as default to auto-detect width.
         height (int, optional): The height of the terminal. Leave as default to auto-detect height.
         record (bool, optional): Boolean to enable recording of terminal output,
@@ -516,7 +562,7 @@ class Console:
         Returns:
             str: Console output.
         """
-        render_result = self._render_buffer()
+        render_result = self._render_buffer(self._buffer)
         del self._buffer[:]
         self._exit_buffer()
         return render_result
@@ -568,7 +614,7 @@ class Console:
         Returns:
             str: A standard encoding string.
         """
-        return getattr(self.file, "encoding", "utf-8")
+        return (getattr(self.file, "encoding", "utf-8") or "utf-8").lower()
 
     @property
     def is_terminal(self) -> bool:
@@ -599,6 +645,7 @@ class Console:
     def options(self) -> ConsoleOptions:
         """Get default console options."""
         return ConsoleOptions(
+            legacy_windows=self.legacy_windows,
             min_width=1,
             max_width=self.width,
             encoding=self.encoding,
@@ -620,7 +667,7 @@ class Console:
             return ConsoleDimensions(80, 25)
 
         width, height = shutil.get_terminal_size()
-        # get_terminal_size can report 0, 0 if run from psuedo-terminal
+        # get_terminal_size can report 0, 0 if run from pseudo-terminal
         width = width or 80
         height = height or 25
         return ConsoleDimensions(
@@ -659,6 +706,29 @@ class Console:
         capture = Capture(self)
         return capture
 
+    def pager(
+        self, pager: Pager = None, styles: bool = False, links: bool = False
+    ) -> PagerContext:
+        """A context manager to display anything printed within a "pager". The pager used
+        is defined by the system and will typically support at less pressing a key to scroll.
+
+        Args:
+            pager (Pager, optional): A pager object, or None to use :class:~rich.pager.SystemPager`. Defaults to None.
+            styles (bool, optional): Show styles in pager. Defaults to False.
+            links (bool, optional): Show links in pager. Defaults to False.
+
+        Example:
+            >>> from rich.console import Console
+            >>> from rich.__main__ import make_test_card
+            >>> console = Console()
+            >>> with console.pager():
+                    console.print(make_test_card())
+
+        Returns:
+            PagerContext: A context manager.
+        """
+        return PagerContext(self, pager=pager, styles=styles, links=links)
+
     def line(self, count: int = 1) -> None:
         """Write new line(s).
 
@@ -749,7 +819,7 @@ class Console:
         is required, such as the Panel class which draws a border around any renderable object.
 
         Args:
-            renderables (Iterable[RenderableType]): Any object or objects renderable in the console.
+            renderable (RenderableType): Any object renderable in the console.
             options (Optional[ConsoleOptions], optional): Console options, or None to use self.options. Default to ``None``.
             style (Style, optional): Optional style to apply to renderables. Defaults to ``None``.
             pad (bool, optional): Pad lines shorter than render width. Defaults to ``True``.
@@ -858,7 +928,7 @@ class Console:
         """Combined a number of renderables and text in to one renderable.
 
         Args:
-            renderables (Iterable[Union[str, ConsoleRenderable]]): Anything that Rich can render.
+            objects (Iterable[Any]): Anything that Rich can render.
             sep (str, optional): String to write between print data. Defaults to " ".
             end (str, optional): String to write at end of print data. Defaults to "\\n".
             justify (str, optional): One of "left", "right", "center", or "full". Defaults to ``None``.
@@ -920,7 +990,7 @@ class Console:
 
     def rule(
         self,
-        title: str = "",
+        title: TextType = "",
         *,
         characters: str = "─",
         style: Union[str, Style] = "rule.line",
@@ -946,6 +1016,37 @@ class Console:
             self._buffer.append(Segment.control(str(control_codes)))
             self._check_buffer()
 
+    def out(
+        self,
+        *objects: Any,
+        sep=" ",
+        end="\n",
+        style: Union[str, Style] = None,
+        highlight: bool = True,
+    ) -> None:
+        """Output to the terminal. This is a low-level way of writing to the terminal which unlike
+        :meth:`~rich.console.Console.print` doesn't pretty print, wrap text, nor markup, but will highlighting
+        and apply basic style.
+
+        Args:
+            sep (str, optional): String to write between print data. Defaults to " ".
+            end (str, optional): String to write at end of print data. Defaults to "\\n".
+            style (Union[str, Style], optional): A style to apply to output. Defaults to None.
+            highlight (Optional[bool], optional): Enable automatic highlighting, or ``None`` to use console default. Defaults to ``None``.
+        """
+        raw_output: str = sep.join(str(_object) for _object in objects)
+        self.print(
+            raw_output,
+            style=style,
+            highlight=highlight,
+            emoji=False,
+            markup=False,
+            no_wrap=True,
+            overflow="ignore",
+            crop=False,
+            end=end,
+        )
+
     def print(
         self,
         *objects: Any,
@@ -1146,7 +1247,8 @@ class Console:
                     display(self._buffer)
                     del self._buffer[:]
                 else:
-                    text = self._render_buffer()
+                    text = self._render_buffer(self._buffer[:])
+                    del self._buffer[:]
                     if text:
                         try:
                             if WINDOWS:  # pragma: no cover
@@ -1161,17 +1263,15 @@ class Console:
                             error.reason = f"{error.reason}\n*** You may need to add PYTHONIOENCODING=utf-8 to your environment ***"
                             raise
 
-    def _render_buffer(self) -> str:
+    def _render_buffer(self, buffer: Iterable[Segment]) -> str:
         """Render buffered output, and clear buffer."""
         output: List[str] = []
         append = output.append
         color_system = self._color_system
         legacy_windows = self.legacy_windows
-        buffer = self._buffer[:]
         if self.record:
             with self._record_buffer_lock:
                 self._record_buffer.extend(buffer)
-        del self._buffer[:]
         not_terminal = not self.is_terminal
         for text, style, is_control in buffer:
             if style and not is_control:
@@ -1366,7 +1466,7 @@ class Console:
             clear (bool, optional): Clear record buffer after exporting. Defaults to ``True``.
             code_format (str, optional): Format string to render HTML, should contain {foreground}
                 {background} and {code}.
-            inline_styes (bool, optional): If ``True`` styles will be inlined in to spans, which makes files
+            inline_styles (bool, optional): If ``True`` styles will be inlined in to spans, which makes files
                 larger but easier to cut and paste markup. If ``False``, styles will be embedded in a style tag.
                 Defaults to False.
 
@@ -1413,7 +1513,7 @@ if __name__ == "__main__":  # pragma: no cover
                         "options": [
                             "New York Bulls",
                             "Los Angeles Kings",
-                            "Golden State Warriros",
+                            "Golden State Warriors",
                             "Huston Rocket",
                         ],
                         "answer": "Huston Rocket",
